==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Magazyn.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.TypMagazynu;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Magazyn extends GenericDPSObject {
    /**
     * MAGAZYN.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypMagazynu typ;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return MAGAZYN.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypMagazynu getTyp() {
        return typ;
    }

    /**
     * MAGAZYN.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypMagazynu typ) {
        this.typ = typ;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Magazyn other = (Magazyn) that;
        return (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", typ=").append(typ);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Magazyn.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.TypMagazynu;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Magazyn extends GenericDPSObject {
    /**
     * MAGAZYN.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypMagazynu typ;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return MAGAZYN.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypMagazynu getTyp() {
        return typ;
    }

    /**
     * MAGAZYN.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypMagazynu typ) {
        this.typ = typ;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Magazyn other = (Magazyn) that;
        return (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", typ=").append(typ);
        sb.append("]");
        return sb.toString();
    }
}
